@@ -31,5 +31,7 @@
 """Flax API."""
 
 # Allow `import flax`; `flax.nn.[...]`, and the same for `flax.optim.[...]`
+from . import core
+from . import linen
 from . import nn
 from . import optim
