@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """NN base modules for JAX."""
 
 import abc
@@ -1118,11 +1117,13 @@ jax.tree_util.register_pytree_node(Collection,
 
 
 def _collection_state_dict(collection):
-  return collection.as_dict()
+  return serialization._dict_state_dict(collection.as_dict())  # pylint: disable=protected-access
 
 
-def _collection_from_state_dict(_, state):
-  return Collection(state)
+def _collection_from_state_dict(xs, state):
+  restored_state = serialization._restore_dict(xs.as_dict(), state)  # pylint: disable=protected-access
+
+  return Collection(restored_state)
 
 
 serialization.register_serialization_state(
